==> haskell-hyphenation-0.8.3-102.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hyphenation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hyphenation
version:              0.8.3
visibility:           public
id:                   hyphenation-0.8.3-2Ur28Fsn9FlnKPimcvVaI
key:                  hyphenation-0.8.3-2Ur28Fsn9FlnKPimcvVaI
license:              BSD-2-Clause
copyright:            (C) 2012-2019 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/hyphenation
synopsis:             Configurable Knuth-Liang hyphenation
description:
    Configurable Knuth-Liang hyphenation

    Uses the UTF8 encoded hyphenation patterns provided by
    hyph-utf8 from
    <http://www.ctan.org/tex-archive/language/hyph-utf8>

    Usage:

    >>> hyphenate english_US "supercalifragilisticexpialadocious"
    ["su","per","cal","ifrag","ilis","tic","ex","pi","al","ado","cious"]

    >>> hyphenate english_US "hyphenation"
    ["hy","phen","ation"]

    >>> hyphenate icelandic "va\240lahei\240avegavinnuverkf\230rageymslusk\250r"
    ["va\240la","hei\240a","vega","vinnu","verk","f\230ra","geymslu","sk\250r"]

category:             Text
abi:                  ead381fa2452444e483cd11ba335b1d5
exposed:              True
exposed-modules:
    Text.Hyphenation Text.Hyphenation.Exception
    Text.Hyphenation.Hyphenator Text.Hyphenation.Language
    Text.Hyphenation.Pattern

hidden-modules:       Paths_hyphenation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hyphenation-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hyphenation-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hyphenation-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hyphenation
hs-libraries:         HShyphenation-0.8.3-2Ur28Fsn9FlnKPimcvVaI
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz text-2.0.2
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    zlib-0.7.0.0-5otxZx3SVlrUZcbECZKz5

haddock-interfaces:   /usr/share/doc/haskell-hyphenation/html/hyphenation.haddock
haddock-html:         /usr/share/doc/haskell-hyphenation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hyphenation-0.8.3-103-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hyphenation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hyphenation
version:              0.8.3
visibility:           public
id:                   hyphenation-0.8.3-Fd22WswabcT3hPdNrbqwcg
key:                  hyphenation-0.8.3-Fd22WswabcT3hPdNrbqwcg
license:              BSD-2-Clause
copyright:            (C) 2012-2019 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/hyphenation
synopsis:             Configurable Knuth-Liang hyphenation
description:
    Configurable Knuth-Liang hyphenation

    Uses the UTF8 encoded hyphenation patterns provided by
    hyph-utf8 from
    <http://www.ctan.org/tex-archive/language/hyph-utf8>

    Usage:

    >>> hyphenate english_US "supercalifragilisticexpialadocious"
    ["su","per","cal","ifrag","ilis","tic","ex","pi","al","ado","cious"]

    >>> hyphenate english_US "hyphenation"
    ["hy","phen","ation"]

    >>> hyphenate icelandic "va\240lahei\240avegavinnuverkf\230rageymslusk\250r"
    ["va\240la","hei\240a","vega","vinnu","verk","f\230ra","geymslu","sk\250r"]

category:             Text
abi:                  2856b9ddce0ac025fa94248ecbb8b956
exposed:              True
exposed-modules:
    Text.Hyphenation Text.Hyphenation.Exception
    Text.Hyphenation.Hyphenator Text.Hyphenation.Language
    Text.Hyphenation.Pattern

hidden-modules:       Paths_hyphenation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hyphenation-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hyphenation-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hyphenation-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hyphenation
hs-libraries:         HShyphenation-0.8.3-Fd22WswabcT3hPdNrbqwcg
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz text-2.0.2
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    zlib-0.7.0.0-H0rgJT2cf7y1jpEf30oLpw

haddock-interfaces:   /usr/share/doc/haskell-hyphenation/html/hyphenation.haddock
haddock-html:         /usr/share/doc/haskell-hyphenation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
